/**
 * Copyright (c) 2005 Red Hat, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Component of: Red Hat Application Server
 *
 * Initial Developers: Vadim Nasardinov (vadimn@redhat.com)
 */
package org.ow2.carol.irmi;

/**
 * An unchecked exception that adds the thread name to the message.
 *
 * <p>This is useful because IRMI threads have names that help identify the
 * context in which they were spawned.</p>
 *
 * @author Vadim Nasardinov &lt;vadimn@redhat.com&gt;
 **/

public class IRMIException extends RuntimeException {

    public IRMIException(String msg) {
        super(threadInfo(msg));
    }

    public IRMIException(String msg, Throwable cause) {
        super(threadInfo(msg), cause);
    }

    public IRMIException(Throwable cause) {
        this((String) null, cause);
    }

    private static String threadInfo(String msg) {
        final Thread current = Thread.currentThread();
        final StringBuffer sb = new StringBuffer();
        sb.append("Exception in thread: ").append(current.getName());
        if (msg != null) {
            sb.append(": ").append(msg);
        }
        return sb.toString();
    }
}
